General Introduction
::::::::::::::::::::

.. toctree::
   :caption: General Introduction
   :maxdepth: 2

   intro-TheWayoftheProgram.rst
   Algorithms.rst
   ThePythonProgrammingLanguage.rst
   SpecialWaystoExecutePythoninthisBook.rst
   MoreAboutPrograms.rst
   WhatisDebugging.rst
   Syntaxerrors.rst
   RuntimeErrors.rst
   SemanticErrors.rst
   ExperimentalDebugging.rst
   FormalandNaturalLanguages.rst
   ATypicalFirstProgram.rst
   Comments.rst
   Glossary.rst
   Exercises.rst
   